@@ -100,14 +100,12 @@ update.multinom_reg <-
 # ------------------------------------------------------------------------------
 
 #' @export
-check_args.multinom_reg <- function(object) {
+check_args.multinom_reg <- function(object, call = rlang::caller_env()) {
 
   args <- lapply(object$args, rlang::eval_tidy)
 
-  if (all(is.numeric(args$penalty)) && any(args$penalty < 0))
-    rlang::abort("The amount of regularization should be >= 0.")
-  if (is.numeric(args$mixture) && (args$mixture < 0 | args$mixture > 1))
-    rlang::abort("The mixture proportion should be within [0,1].")
+  check_number_decimal(args$mixture, min = 0, max = 1, allow_null = TRUE, call = call, arg = "mixture")
+  check_number_decimal(args$penalty, min = 0, allow_null = TRUE, call = call, arg = "penalty")
 
   invisible(object)
 }
