@@ -9,21 +9,25 @@
 #' @export predict_class.model_fit
 #' @export
 predict_class.model_fit <- function(object, new_data, ...) {
-  if (object$spec$mode != "classification")
-    rlang::abort("`predict.model_fit()` is for predicting factor outcomes.")
+  if (object$spec$mode != "classification") {
+    cli::cli_abort("{.fun predict.model_fit} is for predicting factor outcomes.",
+                   call = rlang::call2("predict"))
+  }
 
   check_spec_pred_type(object, "class")
 
   if (inherits(object$fit, "try-error")) {
-    rlang::warn("Model fit failed; cannot make predictions.")
+    cli::cli_warn("Model fit failed; cannot make predictions.",
+                  call = rlang::call2("predict"))
     return(NULL)
   }
 
   new_data <- prepare_data(object, new_data)
 
   # preprocess data
-  if (!is.null(object$spec$method$pred$class$pre))
+  if (!is.null(object$spec$method$pred$class$pre)) {
     new_data <- object$spec$method$pred$class$pre(new_data, object)
+  }
 
   # create prediction call
   pred_call <- make_pred_call(object$spec$method$pred$class)
@@ -37,14 +41,16 @@ predict_class.model_fit <- function(object, new_data, ...) {
 
   # coerce levels to those in `object`
   if (is.vector(res) || is.factor(res)) {
-    res <- factor(as.character(res), levels = object$lvl)
+    res <- factor(as.character(res), levels = object$lvl, ordered = object$ordered)
   } else {
     if (!inherits(res, "tbl_spark")) {
       # Now case where a parsnip model generated `res`
       if (is.data.frame(res) && ncol(res) == 1 && is.factor(res[[1]])) {
         res <- res[[1]]
       } else {
-        res$values <- factor(as.character(res$values), levels = object$lvl)
+        res$values <- factor(as.character(res$values),
+                             levels = object$lvl,
+                             ordered = object$ordered)
       }
     }
   }
@@ -56,6 +62,6 @@ predict_class.model_fit <- function(object, new_data, ...) {
 # @keywords internal
 # @rdname other_predict
 # @inheritParams predict.model_fit
-predict_class <- function(object, ...)
+predict_class <- function(object, ...) {
   UseMethod("predict_class")
-
+}
