@@ -134,7 +134,7 @@ translate.svm_poly <- function(x, engine = x$engine, ...) {
 # ------------------------------------------------------------------------------
 
 #' @export
-check_args.svm_poly <- function(object) {
+check_args.svm_poly <- function(object, call = rlang::caller_env()) {
   invisible(object)
 }
 
