@@ -1,7 +1,7 @@
 test_that('updating', {
   expect_snapshot(
-    nearest_neighbor(neighbors = 5) %>%
-      set_engine("kknn", scale = FALSE) %>%
+    nearest_neighbor(neighbors = 5) |>
+      set_engine("kknn", scale = FALSE) |>
       update(neighbors = tune(), scale = tune())
   )
 })
@@ -12,14 +12,15 @@ test_that('bad input', {
 
 test_that('check_args() works', {
   skip_if_not_installed("kknn")
+  skip_if_not_installed("modeldata")
 
   hpc <- hpc_data[1:150, c(2:5, 8)]
 
   expect_snapshot(
     error = TRUE,
     {
-      spec <- nearest_neighbor(neighbors = -1) %>%
-        set_engine("kknn") %>%
+      spec <- nearest_neighbor(neighbors = -1) |>
+        set_engine("kknn") |>
         set_mode("classification")
       fit(spec, class ~ ., hpc)
     }
@@ -27,8 +28,8 @@ test_that('check_args() works', {
   expect_snapshot(
     error = TRUE,
     {
-      spec <- nearest_neighbor(weight_func = 2) %>%
-        set_engine("kknn") %>%
+      spec <- nearest_neighbor(weight_func = 2) |>
+        set_engine("kknn") |>
         set_mode("classification")
       fit(spec, class ~ ., hpc)
     }
