@@ -2,8 +2,8 @@ test_that('updating', {
   rlang::local_options(lifecycle_verbosity = "quiet")
 
   expect_snapshot(
-    surv_reg() %>%
-      set_engine("flexsurv", cl = 0.99) %>%
+    surv_reg() |>
+      set_engine("flexsurv", cl = 0.99) |>
       update(cl = tune())
   )
 })
@@ -12,8 +12,8 @@ test_that('bad input', {
   rlang::local_options(lifecycle_verbosity = "quiet")
 
   expect_snapshot(error = TRUE, surv_reg(mode = ", classification"))
-  expect_snapshot(error = TRUE, translate(surv_reg() %>% set_engine("wat")))
-  expect_snapshot(res <- translate(surv_reg() %>% set_engine(NULL)), error = TRUE)
+  expect_snapshot(error = TRUE, translate(surv_reg() |> set_engine("wat")))
+  expect_snapshot(res <- translate(surv_reg() |> set_engine(NULL)), error = TRUE)
 })
 
 test_that("deprecation warning", {
