@@ -1,15 +1,13 @@
-data(cancer, package = "survival")
 
-basic_form <- survival::Surv(time, status) ~ age
-complete_form <- survival::Surv(time) ~ age
 
 # ------------------------------------------------------------------------------
 
 test_that('flexsurv execution', {
   skip_if_not_installed("flexsurv")
+  skip_if_not_installed("survival")
 
   rlang::local_options(lifecycle_verbosity = "quiet")
-  surv_basic <- surv_reg() %>% set_engine("flexsurv")
+  surv_basic <- surv_reg() |> set_engine("flexsurv")
 
   expect_no_condition(
     res <- fit(
@@ -43,9 +41,11 @@ test_that('flexsurv execution', {
 
 test_that('flexsurv prediction', {
   skip_if_not_installed("flexsurv")
+  skip_if_not_installed("survival")
+
 
   rlang::local_options(lifecycle_verbosity = "quiet")
-  surv_basic <- surv_reg() %>% set_engine("flexsurv")
+  surv_basic <- surv_reg() |> set_engine("flexsurv")
 
   res <- fit(
     surv_basic,
