@@ -1,19 +1,12 @@
-if (R.Version()$major < "4") {
-  data(lung, package = 'survival')
-} else {
-  data(cancer, package = 'survival')
-}
 
-basic_form <- survival::Surv(time, status) ~ group
-complete_form <- survival::Surv(time) ~ group
 
 # ------------------------------------------------------------------------------
 
 test_that('survival execution', {
   skip_if_not_installed("survival")
   rlang::local_options(lifecycle_verbosity = "quiet")
-  surv_basic <- surv_reg() %>% set_engine("survival")
-  surv_lnorm <- surv_reg(dist = "lognormal") %>% set_engine("survival")
+  surv_basic <- surv_reg() |> set_engine("survival")
+  surv_lnorm <- surv_reg(dist = "lognormal") |> set_engine("survival")
 
   expect_no_condition(
     res <- fit(
@@ -47,8 +40,8 @@ test_that('survival prediction', {
   skip_if_not_installed("survival")
 
   rlang::local_options(lifecycle_verbosity = "quiet")
-  surv_basic <- surv_reg() %>% set_engine("survival")
-  surv_lnorm <- surv_reg(dist = "lognormal") %>% set_engine("survival")
+  surv_basic <- surv_reg() |> set_engine("survival")
+  surv_lnorm <- surv_reg(dist = "lognormal") |> set_engine("survival")
 
   res <- fit(
     surv_basic,
